@@ -6,6 +6,7 @@ require 'rspec-puppet/errors'
 require 'rspec-puppet/matchers'
 require 'rspec-puppet/example'
 require 'rspec-puppet/setup'
+require 'rspec-puppet/coverage'
 
 begin
   require 'puppet/test/test_helper'
@@ -13,6 +14,7 @@ rescue LoadError
 end
 
 RSpec.configure do |c|
+  c.add_setting :environmentpath, :default => '/etc/puppetlabs/code/environments'
   c.add_setting :module_path, :default => '/etc/puppet/modules'
   c.add_setting :manifest_dir, :default => nil
   c.add_setting :manifest, :default => nil
@@ -21,6 +23,11 @@ RSpec.configure do |c|
   c.add_setting :confdir, :default => '/etc/puppet'
   c.add_setting :default_facts, :default => {}
   c.add_setting :hiera_config, :default => '/dev/null'
+  c.add_setting :parser, :default => 'current'
+  c.add_setting :trusted_node_data, :default => false
+  c.add_setting :ordering, :default => 'title-hash'
+  c.add_setting :stringify_facts, :default => true
+  c.add_setting :strict_variables, :default => false
 
   if defined?(Puppet::Test::TestHelper)
     begin
