@@ -3,8 +3,8 @@ module RSpec::Puppet
     include RSpec::Puppet::ManifestMatchers
     include RSpec::Puppet::Support
 
-    def subject
-      @catalogue ||= catalogue(:define)
+    def catalogue
+      @catalogue ||= load_catalogue(:define)
     end
   end
 end
